@@ -12,16 +12,21 @@ from zinnia.settings import ENTRY_BASE_MODEL
 
 
 class EntryPlaceholderAdmin(PlaceholderAdmin, EntryAdmin):
-    """EntryPlaceholder Admin"""
-    fieldsets = ((None, {'fields': ('title', 'image', 'status')}),
-                 (_('Content'), {'fields': ('content_placeholder',),
-                                 'classes': ('plugin-holder',
-                                             'plugin-holder-nopage')})) + \
-                                             EntryAdmin.fieldsets[1:]
+    """
+    EntryPlaceholder Admin
+    """
+    fieldsets = (
+        (None, {'fields': ('title', 'image', 'status')}),
+        (_('Content'), {'fields': ('content_placeholder',),
+                        'classes': ('plugin-holder',
+                                    'plugin-holder-nopage')})) + \
+        EntryAdmin.fieldsets[1:]
 
     def save_model(self, request, entry, form, change):
-        """Fill the content field with the interpretation
-        of the placeholder"""
+        """
+        Fill the content field with the interpretation
+        of the placeholder
+        """
         context = RequestContext(request)
         entry.content = render_placeholder(entry.content_placeholder, context)
         super(EntryPlaceholderAdmin, self).save_model(
